From 631e71a6cf14c8a3e8e0435bbae5bf8934428733 Mon Sep 17 00:00:00 2001
From: Jean-Baptiste Lallement <jeanbaptiste.lallement@gmail.com>
Date: Fri, 24 Oct 2014 12:30:14 -0400
Subject: [PATCH] support/dkms: add support for dkms packages

---
 debian/changelog      |  4 ++++
 support/dkms/detect   |  7 +++++++
 support/dkms/generate |  7 +++++++
 test.sh               | 37 +++++++++++++++++++++++++++++++++++++
 4 files changed, 55 insertions(+)
 create mode 100755 support/dkms/detect
 create mode 100755 support/dkms/generate

diff --git a/debian/changelog b/debian/changelog
index 94c5148..900ab17 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,7 +1,11 @@
 autodep8 (0.2) UNRELEASED; urgency=medium
 
+  [ Antonio Terceiro ]
   * debian/control: add Vcs-* fields
 
+  [ Jean-Baptiste Lallement ]
+  * support/dkms: add support for dkms packages
+
  -- Antonio Terceiro <terceiro@debian.org>  Tue, 14 Oct 2014 15:25:18 -0300
 
 autodep8 (0.1) unstable; urgency=medium
diff --git a/support/dkms/detect b/support/dkms/detect
new file mode 100755
index 0000000..955a5c0
--- /dev/null
+++ b/support/dkms/detect
@@ -0,0 +1,7 @@
+#!/bin/sh
+
+set -eu
+
+grep-dctrl --quiet \
+    -FBuild-Depends,Build-Depends-Indep,Depends -e '(^| )dkms' \
+    -o -FPackage -e '\-dkms' debian/control
diff --git a/support/dkms/generate b/support/dkms/generate
new file mode 100755
index 0000000..2c344e2
--- /dev/null
+++ b/support/dkms/generate
@@ -0,0 +1,7 @@
+#!/bin/sh
+
+cat <<EOF
+Test-Command: /usr/lib/dkms/dkms-autopkgtest
+Restrictions: needs-root, isolation-machine, breaks-testbed, allow-stderr
+Depends: dkms
+EOF
diff --git a/test.sh b/test.sh
index ceb9461..47a4ebd 100755
--- a/test.sh
+++ b/test.sh
@@ -35,6 +35,16 @@ test_XS_Testsuite_autopkgtest_pkg_nodejs() {
   check_run autodep8
 }
 
+test_Testsuite_autopkgtest_pkg_dkms() {
+  has debian/control 'Testsuite: autopkgtest-pkg-dkms'
+  check_run autodep8
+}
+
+test_XS_Testsuite_autopkgtest_pkg_dkms() {
+  has debian/control 'XS-Testsuite: autopkgtest-pkg-dkms'
+  check_run autodep8
+}
+
 test_ruby_rake() {
   has debian/ruby-tests.rake
   check_run autodep8
@@ -100,6 +110,33 @@ test_nodejs_upstream_name() {
   assertFalse 'does not include node- prefix' 'grep --quiet node-foo stdout'
 }
 
+test_detect_dkms_depends() {
+  has 'debian/control' 'Depends: dkms'
+  check_run autodep8
+}
+
+test_detect_dkms_builddepends() {
+  has 'debian/control' 'Build-Depends: dkms'
+  check_run autodep8
+}
+
+test_detect_dkms_builddepends_indep() {
+  has 'debian/control' 'Build-Depends-Indep: dkms'
+  check_run autodep8
+}
+
+test_detect_dkms_packagename() {
+  has 'debian/control' 'Package: foo-dkms'
+  check_run autodep8
+}
+
+test_dkms_depends_dkms() {
+  has 'debian/control' "Depends: dkms"
+  check_run autodep8
+  assertFalse "test does must depend on dkms\n$(grep Depends: stdout)\n" "grep -q Depends:.*depends stdout"
+}
+
+
 ##################################################
 
 if [ -z "$ADTTMP" ]; then
-- 
2.1.0

